package logUtil

// ILog
// @description: 日志接口
type ILog interface {
	// InfoLog
	// @description: 信息日志记录
	// parameter:
	//		@format:日志格式
	//		@args:参数列表
	// return:
	InfoLog(format string, args ...interface{})

	// DebugLog
	// @description: 调试日志记录
	// parameter:
	//		@format:日志格式
	//		@args:参数列表
	// return:
	DebugLog(format string, args ...interface{})

	// WarnLog
	// @description: 警告日志记录
	// parameter:
	//		@format:日志格式
	//		@args:参数列表
	// return:
	WarnLog(format string, args ...interface{})

	// ErrorLog
	// @description: 错误日志记录
	// parameter:
	//		@format:日志格式
	//		@args:参数列表
	// return:
	ErrorLog(format string, args ...interface{})

	// FatalLog
	// @description: 致命错误日志记录
	// parameter:
	//		@format:日志格式
	//		@args:参数列表
	// return:
	FatalLog(format string, args ...interface{})

	// CloseLog
	// @description: 关闭日志
	// parameter:
	//		@waitFinish:是否等待日志
	// return:
	CloseLog(waitFinish bool)
}
